@@ -41,8 +41,12 @@ def data_handler(request, secret):
         order.request_ip = ip
         order.save()
         signals.data.send(sender = data_handler, order=order)
-        return HttpResponse('OK')
-    return HttpResponse('error')
+        return HttpResponse()
+
+    errors = form.plain_errors()[:255]
+    order.debug_info = errors
+    order.save()
+    return HttpResponse(errors)
 
 
 @csrf_exempt
